@@ -84,7 +84,6 @@ def convert_dash(mpl_dash):
 
 
 def convert_path(path):
-    verts = path[0]  # may use this later
     code = tuple(path[1])
     if code in PATH_MAP:
         return PATH_MAP[code]
@@ -493,7 +492,7 @@ def prep_ticks(ax, index, ax_type, props):
         else:
             axis_dict = dict(range=None, type="linear")
             warnings.warn(
-                "Converted non-base10 {0}-axis log scale to 'linear'" "".format(ax_type)
+                "Converted non-base10 {0}-axis log scale to 'linear'".format(ax_type)
             )
     else:
         return dict()
@@ -553,7 +552,7 @@ def mpl_dates_to_datestrings(dates, mpl_formatter):
         try:
             dates = matplotlib.dates.epoch2num([date * 24 * 60 * 60 for date in dates])
             dates = matplotlib.dates.num2date(dates)
-        except:
+        except Exception:
             return _dates
 
     # the rest of mpl dates are in floating point days since
@@ -562,7 +561,7 @@ def mpl_dates_to_datestrings(dates, mpl_formatter):
     else:
         try:
             dates = matplotlib.dates.num2date(dates)
-        except:
+        except Exception:
             return _dates
 
     time_stings = [
